window.Gleam.initSearch([{"doc":"glimra","title":"glimra","content":"# glimra\n\n[![Package Version](https://img.shields.io/hexpm/v/glimra)](https://hex.pm/packages/glimra)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glimra/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)\n\nZero runtime syntax highlighter for [`lustre/ssg`](https://github.com/lustre-labs/ssg).\n\n&gt; In Swedish, `glimra` describes the brilliant gleam or lustre that comes from a polished, reflective surface, capturing the essence of light shining off something smooth and glossy.\n\n## Platform support\n\n`glimra` uses [NIFs](https://www.erlang.org/doc/system/nif) to extract syntax highlighting events provided by the [`tree-sitter`](https://crates.io/crates/tree-sitter) and [`tree-sitter-highlight`](https://crates.io/crates/tree-sitter-highlight) crates. This allows `glimra` to provide syntax highlighting for a wide range of languages with minimal effort.\n\nUnfortunately, this also means that `glimra` only works with the Erlang target. Furthermore, you either need to have access to the Rust toolchain or you can use the provided precompiled binaries.\n\nCurrently, the following operating systems and architectures are supported:\n\n| OS      | Architecture(s) |\n| ------- | --------------- |\n| Linux   | x86_64          |\n| macOS   | aarch64, x86_64 |\n| Windows | x86_64          |\n\n## Installation\n\n```sh\ngleam add glimra\n```\n\n## Usage\n\n```gleam\nimport glimra\n\npub fn main() {\n  let source = &quot;let greeting = \\&quot;Hello, Joe!\\&quot;&quot;\n\n  let highlighted_snippet =\n    glimra.syntax_highlighter(language: &quot;gleam&quot;)\n    |&gt; glimra.syntax_highlight(source: source)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glimra&gt;.\n\n## Development\n\n```sh\ngleam test  # run the tests\n```\n","url":"index.html"},{"doc":"glimra","title":"Config","content":"pub opaque type Config\n\n\nSynonyms:\nglimra.Config\nglimra Config","url":"glimra.html#Config"},{"doc":"glimra","title":"SyntaxHighlightingError","content":"pub type SyntaxHighlightingError {\n  UnsupportedLanguage(language: String)\n  TreeSitterError\n  UnmatchedHighlightEvents\n}\n\nUnsupportedLanguage(language: String)\n\n\nTreeSitterError\n\n\nUnmatchedHighlightEvents\n\n\nSynonyms:\nglimra.SyntaxHighlightingError\nglimra SyntaxHighlightingError","url":"glimra.html#SyntaxHighlightingError"},{"doc":"glimra","title":"block_class","content":"pub fn block_class(\n  config config: Config,\n  class class: String,\n) -&gt; Config\n\nSynonyms:\nglimra.block_class\nglimra block_class","url":"glimra.html#block_class"},{"doc":"glimra","title":"line_class","content":"pub fn line_class(\n  config config: Config,\n  class class: String,\n) -&gt; Config\n\nSynonyms:\nglimra.line_class\nglimra line_class","url":"glimra.html#line_class"},{"doc":"glimra","title":"syntax_highlight","content":"pub fn syntax_highlight(\n  config config: Config,\n  source source: String,\n) -&gt; Result(Element(Nil), SyntaxHighlightingError)\n\nSynonyms:\nglimra.syntax_highlight\nglimra syntax_highlight","url":"glimra.html#syntax_highlight"},{"doc":"glimra","title":"syntax_highlighter","content":"pub fn syntax_highlighter(language language: String) -&gt; Config\n\nSynonyms:\nglimra.syntax_highlighter\nglimra syntax_highlighter","url":"glimra.html#syntax_highlighter"},{"doc":"glimra","title":"glimra","content":"","url":"glimra.html"}]);